VOL-2728 - Do not inform logical_device_manager for PON port state updates

Change-Id: Ie3ccf7ca02150d22a295e9e3b4458a69995ffe1b
diff --git a/VERSION b/VERSION
index 76f4151..f70451d 100644
--- a/VERSION
+++ b/VERSION
@@ -1 +1 @@
-2.3.4-dev
+2.3.5-dev
diff --git a/rw_core/core/device_manager.go b/rw_core/core/device_manager.go
index 714c535..98c45eb 100755
--- a/rw_core/core/device_manager.go
+++ b/rw_core/core/device_manager.go
@@ -879,18 +879,21 @@
 			return err
 		}
 		// Notify the logical device manager to change the port state
-		go func() {
-			err := dMgr.logicalDeviceMgr.updatePortState(context.Background(), deviceID, portNo, operStatus)
-			if err != nil {
-				// While we want to handle (catch) and log when
-				// an update to a port was not able to be
-				// propagated to the logical port, we can report
-				// it as a warning and not an error because it
-				// doesn't stop or modify processing.
-				// TODO: VOL-2707
-				log.Warnw("unable-to-update-logical-port-state", log.Fields{"error": err})
-			}
-		}()
+		// Do this for NNI and UNIs only. PON ports are not known by logical device
+		if portType == voltha.Port_ETHERNET_NNI || portType == voltha.Port_ETHERNET_UNI {
+			go func() {
+				err := dMgr.logicalDeviceMgr.updatePortState(context.Background(), deviceID, portNo, operStatus)
+				if err != nil {
+					// While we want to handle (catch) and log when
+					// an update to a port was not able to be
+					// propagated to the logical port, we can report
+					// it as a warning and not an error because it
+					// doesn't stop or modify processing.
+					// TODO: VOL-2707
+					log.Warnw("unable-to-update-logical-port-state", log.Fields{"error": err})
+				}
+			}()
+		}
 	}
 	return status.Errorf(codes.NotFound, "%s", deviceID)
 }